# OpenHydroponics documentation

```{toctree}
:hidden: true
:titlesonly: true

gettingstarted
software
hardware
```

OpenHydroponics is an open-source project aimed at automating and optimizing hydroponic systems. This documentation provides detailed information on the software and hardware components used in the project.

## Prerequisites

- RootMaster main board
- Raspberry Pi Zero 2W
